@@ -45,7 +45,7 @@
 #define OPENBLAS_CLOCAL_BUFFER_SIZE	16384
 #define OPENBLAS_ZLOCAL_BUFFER_SIZE	12288
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD	4
-#define OPENBLAS_VERSION "OpenBLAS 0.3.10"
+#define OPENBLAS_VERSION "OpenBLAS 0.3.15"
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
@@ -82,6 +82,11 @@ typedef long BLASLONG;
 typedef unsigned long BLASULONG;
 #endif
 
+#ifndef BFLOAT16
+#include <stdint.h>
+typedef uint16_t bfloat16;
+#endif
+
 #ifdef OPENBLAS_USE64BITINT
 typedef BLASLONG blasint;
 #else
